use crate::botv2::init::{Context, Error};
use poise::{
    serenity_prelude::{CreateEmbed, CreateEmbedFooter, CreateMessage},
    CreateReply,
};
use tracing::instrument;

/// List available meme keywords
#[instrument(skip(ctx), level = "info", fields(channel = ctx.channel_id().get(), guild = ?ctx.guild_id().unwrap().get()))]
#[poise::command(slash_command, prefix_command, category = "meme")]
pub async fn list(ctx: Context<'_>) -> Result<(), Error> {
    let config_img = ctx.data().config_img.clone();
    let bot_name = ctx.data().entity_name.clone();
    let list_value: Vec<(String, String, bool)> = config_img
        .keyword
        .iter()
        .map(|x| (x.value.clone().join(", "), String::new(), true))
        .collect();
    if list_value.is_empty() {
        let builder = CreateMessage::new().content("No meme keyword found");
        if let Err(why) = ctx.channel_id().send_message(ctx.http(), builder).await {
            tracing::error!("Error sending message: {:?}", why);
        }
        return Ok(());
    }
    let embed_vec = list_value.chunks(25).map(|chunks| {
        let footer = CreateEmbedFooter::new(bot_name.clone());
        CreateEmbed::new()
            .title("Meme List")
            .fields(chunks.to_vec())
            .footer(footer)
    });
    let reply = CreateReply {
        embeds: embed_vec.collect(),
        ..Default::default()
    };
    if let Err(why) = ctx.send(reply).await {
        tracing::error!("Error sending message: {:?}", why);
    }

    Ok(())
}
