use serde::{Deserialize, Serialize};
use tracing::instrument;

use crate::db::concour::Concour;

#[derive(Serialize, Deserialize, Debug, Clone)]
pub enum GetChannelConcourError {
    FindError(String),
    UnknownError(String),
}

#[instrument(level = "info")]
pub async fn get_channel_concour(
    server_id: u64,
    channel_id: u64,
) -> Result<Option<Concour>, GetChannelConcourError> {
    let concour = match Concour::find_by_server_id_channel_id(&server_id, &channel_id).await {
        Ok(list_concour) => list_concour,
        Err(err) => {
            tracing::error!(error = err.to_string(), "Error finding concour");
            return Err(GetChannelConcourError::UnknownError(
                "Error finding concour".to_string(),
            ));
        }
    };

    Ok(concour)
}
