use serde::{Deserialize, Serialize};
use tracing::{info, instrument};

use crate::db::concour::Concour;

#[derive(Serialize, Deserialize, Debug, Clone)]
pub enum SetPeriodeConcourError {
    DoesntExist,
    FindError(String),
    UnknownError(String),
}

#[instrument(level = "info")]
pub async fn set_periode(
    server_id: u64,
    channel_id: u64,
    periode: String,
) -> Result<Option<Concour>, SetPeriodeConcourError> {
    let concour = match Concour::find_by_server_id_channel_id(&server_id, &channel_id).await {
        Ok(list_concour) => list_concour,
        Err(err) => {
            tracing::error!(error = err.to_string(), "Error finding concour");
            return Err(SetPeriodeConcourError::UnknownError(
                "Error finding concour".to_string(),
            ));
        }
    };

    if concour.is_none() {
        info!("Concour doesn't exist");
        return Err(SetPeriodeConcourError::DoesntExist);
    }

    let mut concour = concour.unwrap();
    concour.periode = periode;

    match concour.update().await {
        Ok(_) => {}
        Err(err) => {
            tracing::error!(error = err.to_string(), "Error updating concour");
            return Err(SetPeriodeConcourError::UnknownError(
                "Error updating concour".to_string(),
            ));
        }
    }
    Ok(Some(concour))
}
