use poise::serenity_prelude::prelude::TypeMapKey;
use regex::Regex;
use serde::Deserialize;
use std::fmt::Debug;
use walkdir::{DirEntry, WalkDir};

#[derive(Deserialize, Clone)]
pub struct KeyWordItem {
    pub value: Vec<String>,
    pub path: Vec<String>,
}

impl KeyWordItem {
    pub fn does_value_match(&self, haystack: String) -> bool {
        self.value.clone().into_iter().any(|val| {
            let re = Regex::new(&val).unwrap();
            re.replace_all(&haystack, "") == ""
        })
    }
    pub fn output_folder_content(path: String) -> Vec<DirEntry> {
        let file_folder: Vec<DirEntry> = WalkDir::new(path)
            .into_iter()
            .filter_entry(|_e| true)
            .filter(|e| {
                if let Some(file) = &e.as_ref().ok() {
                    return !file.metadata().unwrap().is_dir();
                }
                true
            })
            .filter_map(|e| e.ok())
            .collect();
        if file_folder.is_empty() {
            return vec![];
        }
        file_folder
    }
}

impl Debug for KeyWordItem {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        f.debug_struct("KeyWordItem")
            .field("value", &self.value)
            .field("path", &self.path)
            .finish()
    }
}

#[derive(Deserialize, Clone)]
pub struct ConfigFile {
    pub keyword: Vec<KeyWordItem>,
}

impl ConfigFile {
    pub fn parse_config(content: String) -> Result<ConfigFile, serde_yaml::Error> {
        let config: ConfigFile = serde_yaml::from_str(&content)?;
        Ok(config)
    }
}

pub struct ConfigImgGlobal;

impl TypeMapKey for ConfigImgGlobal {
    type Value = ConfigFile;
}
